﻿using System;
using System.Windows;
using Steema.TeeChart.WPF.Styles;
using System.Windows.Threading;

namespace TChartTestApp
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        Random dataRandom = new Random();
        private int InitialPoints = 1000;
        private int TotalSeries = 1;
        // In hrs
        private int X_AxisDuration = 1;
        private int drawInterval = 1; // second
        private double milliSecBetweenPoints;


        private DispatcherTimer drawTimer;

        public Window1()
        {
            InitializeComponent();

            this.Closed += new EventHandler(Trend_Closed);

            tChart.Legend.Visible = false;
            tChart.Chart.Aspect.View3D = false;
            tChart.Walls.View3D = false;
        }

        private void InitializePlot()
        {
            DateTime time = DateTime.Now;
            time = time.Subtract(TimeSpan.FromHours(X_AxisDuration));

            milliSecBetweenPoints = (X_AxisDuration * 60 * 60 * 1000) / InitialPoints;

            tChart.Series.Clear();

            for (int i = 0; i < TotalSeries; i++)
            {
                FastLine fastlineSeries = new FastLine(tChart.Chart);
            }

            Random random = new Random();

            for (int i = 0; i < InitialPoints; i++)
            {
                time = time.AddMilliseconds(milliSecBetweenPoints);

                foreach (FastLine series in tChart.Series)
                {
                    series.Add(time, random.Next(0, 100));
                }
            }

            if (drawTimer != null)
            {
                drawTimer.Stop();
            }

            drawTimer = new DispatcherTimer();
            drawTimer.Interval = TimeSpan.FromSeconds(drawInterval);
            drawTimer.Tick += new EventHandler(drawTimer_Tick);
            drawTimer.Start();
        }

        void drawTimer_Tick(object sender, EventArgs e)
        {
            this.Draw();
        }

        void Trend_Closed(object sender, EventArgs e)
        {
            if (this.drawTimer != null)
            {
                this.drawTimer.Stop();
            }
        }

        void Draw()
        {
            SeriesCollection seriesList = tChart.Series;

            if (seriesList.Count == 0)
            {
                return;
            }
            int i = dataRandom.Next(0, 100);


            DateTime time = DateTime.FromOADate(seriesList[0].XValues[seriesList[0].XValues.Count - 1]);
            time = time.AddMilliseconds(milliSecBetweenPoints);
            foreach (FastLine series in seriesList)
            {
                series.Add(time, i++);

                if (this.chkRemovePoints.IsChecked == true)
                {
                    series.Delete(0);
                    //series.XValues.RemoveAt(0);
                    //series.YValues.RemoveAt(0);
                }
            }
        }

        private void btnApply_Click(object sender, RoutedEventArgs e)
        {
            this.InitialPoints = Convert.ToInt32(this.txtInitialPoints.Text);
            this.TotalSeries = Convert.ToInt32(this.txtSeriesCount.Text);
            this.X_AxisDuration = Convert.ToInt32(this.txtXaxisDuration.Text);
            this.drawInterval = Convert.ToInt32(this.txtDrawInterval.Text);

            InitializePlot();
        }
    }
}
